# Model Interpretation using SHAP

The aim of this module is to provide tools for model interpretation using the [SHAP](https://shap.readthedocs.io/en/latest/) library.
The class below is a convenience wrapper that implements multiple plots for tree-based & linear models.

::: probatus.interpret.model_interpret
::: probatus.interpret.shap_dependence
